api.authentication.v1.test_helpers.constrain package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.test_helpers.constrain package

## Submodules

## api.authentication.v1.test_helpers.constrain.constrain module

`api.authentication.v1.test_helpers.constrain.constrain.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/constrain, respond with HTTP 403

`api.authentication.v1.test_helpers.constrain.constrain.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/constrain, respond with HTTP 404

`api.authentication.v1.test_helpers.constrain.constrain.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/constrain, respond with HTTP 200

`api.authentication.v1.test_helpers.constrain.constrain.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/constrain, respond with HTTP 401

## Module contents